package EPrints::Plugin::MePrints::Layout::Embed;

use strict;

use EPrints::Plugin::MePrints::Layout;
our @ISA = qw/ EPrints::Plugin::MePrints::Layout /;

sub new
{
        my( $class, %params ) = @_;

        my $self = $class->SUPER::new(%params);

        $self->{name} = "Profile Embeddable Widget";

	$self->{user} = $params{user};

	if( defined $params{widgetname} )
	{
		$self->{widgetname} = $params{widgetname};
	}

        return $self;
}

sub render
{
	my( $self ) = @_;
	return $self->html_phrase( "cant_subclass" );
}

# this will return a string so not technically a render method?
sub render_javascript
{
	my( $self ) = @_;

	my $response;

	if( defined $self->{widgetname} )
	{
		$response = $self->_render_embeded_widget;
	}
	else
	{
		$response = $self->_render_embeded_profile;
	}

	return $response;

}

sub _render_embeded_widget
{
	my( $self ) = @_;

	EPrints::abort( "_render_embeded_widget called without defining a widgetname to use. I don't know which widget to render." ) if( !defined $self->{widgetname} );

	my $session = $self->{session};
	my $user = $self->{user};

	my $wname = $self->{widgetname};
	my $widgetname = "MePrints::Widget::".$wname;
	my $repo_name = $self->{session}->phrase( "archive_name" );
	my $repo_url = $self->{session}->get_repository->get_conf( "base_url" );

	my $jsFuncName = "EPRemoteJS_Render".$wname."Widget";
	my $js = <<JAVASCRIPT;
document.getElementById( 'meprints_widget_$wname' ).innerHTML = $jsFuncName();

function $jsFuncName()
{
	var widget = '<div class="ep_remote_js_meprints_embeded">'+
JAVASCRIPT

	my $default_public = 1 if( !EPrints::Utils::is_set( $user->get_value( 'profile_visibility' ) ) && $session->get_repository->get_conf( "default_profile_behaviour" ) );
	if( $user->get_value( 'profile_visibility' ) eq "public" || $default_public )
	{
		my $userid = $user->get_id;
		my $users_name = EPrints::Utils::tree_to_utf8( $user->render_value( 'name' ) );
		my $widget = $session->plugin( $widgetname, user => $user );
		if( defined $widget )
		{
			if( grep( /^$wname$/, @{$session->get_repository->get_conf( 'user_profile_defaults' )} ) )
			{
				my $widget_str = "<div id=\"".$widget->get_id."\" class=\"ep_remote_js_meprints_embeded_widget\"><span class=\"ep_remote_js_meprints_embeded_widget_title\">".$widget->render_title->toString."</span><br/>";
				$widget_str .= "<span class=\"ep_remote_js_meprints_embeded_widget_content\">".$widget->render_content->toString."</span></div>";
				$widget_str =~ s/\'/\\'/g;	
				$js .= <<JAVASCRIPT;
	'$widget_str'+
JAVASCRIPT
			}
			else
			{
				$js .= "'<div class=\"ep_remote_js_meprints_error\">".$self->phrase( 'widget_not_enabled', widgetname => $wname )."</div>'+";
			}
		}
		else
		{
			$js .= "'<div class=\"ep_remote_js_meprints_error\">".$self->phrase( 'widget_does_not_exist', widgetname => $wname )."</div>'+";
		}
	}
	else
	{
		$js .= "'<div class=\"ep_remote_js_meprints_error\">".$self->phrase( 'user_profile_hidden', username => $self->{user}->get_value( 'username' ) )."</div>'+";
	}	

	$js .= <<JAVASCRIPT;
	'<div class="ep_remote_js_meprints_embeded_widget_footer">Generated by <a href="$repo_url">$repo_name</a>.</div>'+
	'</div>';
	return widget;
}
JAVASCRIPT
	
	return $js;
}

sub _render_embeded_profile
{
	my( $self ) = @_;
	
	my $repo_name = $self->{session}->phrase( "archive_name" );
	my $repo_url = $self->{session}->get_repository->get_conf( "base_url" );
	
	my $js = <<JAVASCRIPT;
window.onload = function()
{
	document.getElementById( 'meprints_userprofile' ).innerHTML = EPRemoteJS_RenderUserProfile();
};

function EPRemoteJS_RenderUserProfile()
{
	
	var topbar = '<div class="ep_remote_js_meprints_embeded">'+
JAVASCRIPT
	my $default_public = 1 if(!EPrints::Utils::is_set($self->{user}->get_value( 'profile_visibility' )) && $self->{session}->get_repository()->get_conf("default_profile_behavior"));
	if( $self->{user}->get_value( 'profile_visibility' ) eq "public" || $default_public )
	{
		
		my $userid = $self->{user}->get_id;
		my $users_name = EPrints::Utils::tree_to_utf8($self->{user}->render_value( "name" ));

		my $details_widget = $self->{session}->plugin( "MePrints::Widget::Details", user=>$self->{user} );
		my $details_str = "";
		if( defined $details_str )
		{
			$details_str = "<div id=\"".$details_widget->get_id."\" class=\"ep_remote_js_meprints_embeded_widget\"><span class=\"ep_remote_js_meprints_embeded_widget_title\">".$details_widget->render_title()->toString."</span><br/>";
			$details_str .= "<span class=\"ep_remote_js_meprints_embeded_widget_content\">".$details_widget->render_content()->toString."</span></div>";
			$details_str =~ s/\'/\\'/g;
		}

		my $top_pubs_widget = $self->{session}->plugin( "MePrints::Widget::TopTen", user=>$self->{user} );
		my $top_pubs_str = "";
		if( defined $top_pubs_widget )
		{
			$top_pubs_widget->{max_display} = 5;
			$top_pubs_str = "<div id=\"".$top_pubs_widget->get_id."\" class=\"ep_remote_js_meprints_embeded_widget\"><span class=\"ep_remote_js_meprints_embeded_widget_title\">".$top_pubs_widget->render_title()->toString."</span><br/>";
			$top_pubs_str .= "<span class=\"ep_remote_js_meprints_embeded_widget_content\">".$top_pubs_widget->render_content()->toString."</span></div>";
			$top_pubs_str =~ s/\'/\\'/g;
		}

		my $recent_pubs_widget = $self->{session}->plugin( "MePrints::Widget::LatestEPrints", user=>$self->{user} );
		my $recent_pubs_str = "";
		if( defined $recent_pubs_widget )
		{
			$recent_pubs_widget->{max_display} = 5;
			$recent_pubs_str = "<div id=\"".$recent_pubs_widget->get_id."\" class=\"ep_remote_js_meprints_embeded_widget\"><span class=\"ep_remote_js_meprints_embeded_widget_title\">".$recent_pubs_widget->render_title()->toString."</span><br/>";
			$recent_pubs_str .= "<span class=\"ep_remote_js_meprints_embeded_widget_content\">".$recent_pubs_widget->render_content()->toString."</span></div>";
			$recent_pubs_str =~ s/\'/\\'/g;
		}

		$js .= <<JAVASCRIPT;
	'<div class=\"ep_remote_js_meprints_embeded_header\">'+
	'<a href="$repo_url/profile/$userid">$users_name</a>'+
	'</div>'+
	'<div id=\"ep_remote_meprints_user_profile_image\" class=\"ep_remote_js_meprints_embeded_widget\">'+
	'<img src="$repo_url/cgi/meprints/thumbnail?userid=$userid"/>'+
	'</div>'+
	'$details_str'+	
	'$top_pubs_str'+
	'$recent_pubs_str'+	
JAVASCRIPT
	}
	else
	{
		$js .= "'<div class=\"ep_remote_js_meprints_error\">".$self->phrase( 'user_profile_hidden', username => $self->{user}->get_value( 'username' ) )."</div>'+";
	}

	$js .= <<JAVASCRIPT;
	'<div class="ep_remote_js_meprints_embeded_widget">Generated by <a href="$repo_url">$repo_name</a>.</div>'+
	'</div>';
	return topbar;
}
JAVASCRIPT

	return $js;
}

sub get_layoutmgr_id
{
	my ( $self ) = @_;
	return 'Embed';
}

1;
